Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Tables

Name | Title | Email | Role |
--- | --- | --- | --- | ---
Paweł Kuna | UI Designer, Training | paweluna@howstuffworks.com | User | Edit
Jeffie Lewzey | Chemical Engineer, Support | jlewzey1@seesaa.net | Admin | Edit
Mallory Hulme | Geologist IV, Support | mhulme2@domainmarket.com | User | Edit
Dunn Slane | Research Nurse, Sales | dslane3@epa.gov | Owner | Edit
Emmy Levet | VP Product Management, Accounting | elevet4@senate.gov | Admin | Edit

Name | Title | Email | Role |
--- | --- | --- | --- | ---
Maryjo Lebarree | Civil Engineer, Product Management | mlebarree5@unc.edu | User | Edit
Egan Poetz | Research Nurse, Engineering | epoetz6@free.fr | Admin | Edit
Kellie Skingley | Teacher, Services | kskingley7@columbia.edu | User | Edit
Christabel Charlwood | Tax Accountant, Engineering | ccharlwood8@nifty.com | Owner | Edit
Haskel Shelper | Staff Scientist, Legal | hshelper9@woothemes.com | Admin | Edit

Name | Title | Role |
--- | --- | --- | ---
Lorry Mion lmiona@livejournal.com | Automation Specialist IV Accounting | User | Edit
Leesa Beaty lbeatyb@alibaba.com | Editor Services | Admin | Edit
Perren Keemar pkeemarc@yahoo.com | Analog Circuit Design manager Services | User | Edit
SA Sunny Airey saireyd@prlog.org | Nuclear Power Engineer Engineering | Owner | Edit
Geoffry Flaunders gflaunderse@loc.gov | Software Test Engineer II Accounting | Admin | Edit

Name | Title | Role |
--- | --- | --- | ---
Thatcher Keel tkeelf@blogger.com | VP Sales Business Development | User | Edit
Dyann Escala descalag@usatoday.com | Mechanical Systems Engineer Sales | Admin | Edit
Avivah Mugleston amuglestonh@intel.com | Actuary Sales | User | Edit
AA Arlie Armstead aarmsteadi@yellowpages.com | VP Quality Control Accounting | Owner | Edit
Tessie Curzon tcurzonj@hp.com | Research Nurse Product Management | Admin | Edit

### Invoices

Show
entries
Search:

| No. | Invoice Subject | Client | VAT No. | Created | Status | Price |
--- | --- | --- | --- | --- | --- | --- | --- | ---
| 001401 | Design Works | Carlson Limited | 87956621 | 15 Dec 2017 | Paid | $887 |
| 001402 | UX Wireframes | Adobe | 87956421 | 12 Apr 2017 | Pending | $1200 |
| 001403 | New Dashboard | Bluewolf | 87952621 | 23 Oct 2017 | Pending | $534 |
| 001404 | Landing Page | Salesforce | 87953421 | 2 Sep 2017 | Due in 2 Weeks | $1500 |
| 001405 | Marketing Templates | Printic | 87956621 | 29 Jan 2018 | Paid Today | $648 |
| 001406 | Sales Presentation | Tabdaq | 87956621 | 4 Feb 2018 | Due in 3 Weeks | $300 |
| 001407 | Logo & Print | Apple | 87956621 | 22 Mar 2018 | Paid Today | $2500 |
| 001408 | Icons | Tookapic | 87956621 | 13 May 2018 | Paid Today | $940 |